use chrono::{DateTime, Utc};
use sqlx::PgPool;
use sqlx::types::{chrono, JsonValue};
use sqlx::types::uuid::Bytes;

#[derive(Debug, Clone, Default)]
pub struct Account {
    pub id: String,
    pub username: String,
    pub display_name: Option<String>,
    pub avatar_url: Option<String>,
    pub lang_tag: String,
    pub location: Option<String>,
    pub timezone: Option<String>,
    pub metadata: JsonValue,
    pub wallet: JsonValue,
    pub email: Option<String>,
    pub password: Option<Vec<u8>>,
    pub facebook_id: Option<String>,
    pub google_id: Option<String>,
    pub gamecenter_id: Option<String>,
    pub steam_id: Option<String>,
    pub custom_id: Option<String>,
    pub apple_id: Option<String>,
    pub facebook_instant_game_id: Option<String>,
    pub weixin_id: Option<String>,
    pub douyin_id: Option<String>,
    pub create_time: DateTime<Utc>,
    pub update_time: DateTime<Utc>,
    pub verify_time: DateTime<Utc>,
    pub disable_time: DateTime<Utc>,
}

impl Account {
    // pub async fn find_by_platform_id(platform_id: &str, db_pool: &PgPool) -> Result<Account, sqlx::Error> {
    //     sqlx::query_as!(
    //         Account,
    //         r#"select * from account where platform_id = $1"#,
    //         platform_id
    //     )
    //         .fetch_one(db_pool)
    //         .await
    // }

    // pub async fn add_account_info(player_info: &mut Account, db_pool: &PgPool) -> Result<Account, sqlx::Error> {
    //     sqlx::query_as!(
    //         Account,
    //         r#"
    //         insert into account
    //         (username, email, platform_id, user_type, country_code, created_at, updated_at)
    //         values
    //         ($1, $2, $3, $4, $5, $6, $7) returning *"#,
    //         player_info.username,
    //         player_info.email,
    //         player_info.platform_id,
    //         player_info.user_type,
    //         player_info.country_code,
    //         player_info.created_at,
    //         player_info.updated_at
    //     ).fetch_one(db_pool).await
    // }

    pub async fn add_google_account(&self, db_pool: &PgPool) -> Result<Account, sqlx::Error> {
        sqlx::query_as!(
            Account,
            r#"
               insert into account
               (username, google_id, email, display_name, avatar_url)
               values
               ($1, $2, $3, $4, $5) returning *
            "#,
            self.username,
            self.google_id.clone().unwrap(),
            self.email.clone().unwrap(),
            self.display_name.clone().unwrap(),
            self.avatar_url.clone().unwrap()
        ).fetch_one(db_pool).await
    }
}