use domain::dto::account::AccountRegister;
use domain::entities::account::Account;
use library::db;
use library::resp::response::ResErr::{ErrPerm, ErrSystem};
use library::resp::response::{ResOK, ResResult};

pub async fn register(req: AccountRegister) -> ResResult<ResOK<()>> {

    match Account::add_google_account(
        &mut Account {
            username: req.username.unwrap(),
            email: req.email,
            ..Default::default()
        }, db!()
    ).await {
        Ok(player_info) => {
            tracing::info!("添加账户成功: {:?}", player_info)
        }
        Err(err) => {
            tracing::error!(error = ?err, "添加账号失败");
            return Err(ErrSystem(None));
        }
    }

    Ok(ResOK(None))
}
